@@ -34,13 +34,6 @@
 #include <eel/eel-debug.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <gdk-pixbuf/gdk-pixbuf-loader.h>
-#include <libart_lgpl/art_misc.h>
-#include <libart_lgpl/art_affine.h>
-#include <libart_lgpl/art_pixbuf.h>
-#include <libart_lgpl/art_rgb_pixbuf_affine.h>
-#include <libart_lgpl/art_alphagamma.h>
-
-#include "io-png.h"
 
 #define LOAD_BUFFER_SIZE 65536
 
@@ -454,13 +447,7 @@ save_image_to_stream (BonoboPersistStream *ps, Bonobo_Stream stream,
 		      Bonobo_Persist_ContentType type, void *data,
 		      CORBA_Environment *ev)
 {
-	bonobo_object_data_t *bod = data;
-
-	if (bod->pixbuf == NULL) {
-		return;
-	}
-
-	image_save (stream, bod->pixbuf, ev);
+	g_warning ("save not implemented");
 }
 
 /*
@@ -819,27 +806,12 @@ init_bonobo_image_generic_factory (void)
 static void
 init_server_factory (int argc, char **argv)
 {
-	CORBA_Environment ev;
-	CORBA_exception_init (&ev);
-	
-	/* Disable session manager connection */
-#ifdef GNOME2_CONVERSION_COMPLETE
-	gnome_client_disable_master_connection ();
-
-	gnomelib_register_popt_table (bonobo_activation_popt_options, bonobo_activation_get_popt_table_name ());
-	bonobo_activation_init (argc, argv);
-
-        gnome_init ("bonobo-image-generic", VERSION,
-		    argc, argv); 
-	gdk_rgb_init ();
-
-	if (!bonobo_init (CORBA_OBJECT_NIL, CORBA_OBJECT_NIL, CORBA_OBJECT_NIL))
-		g_error (_("I could not initialize Bonobo"));
-#endif
 	if (!bonobo_ui_init ("bonobo-image-generic", VERSION, &argc, argv))
 		g_error (_("I could not initialize Bonobo"));
 
-	CORBA_exception_free (&ev);
+	/* Disable session manager connection */
+	g_object_set (G_OBJECT (gnome_program_get()),
+	              GNOME_CLIENT_PARAM_SM_CONNECT, FALSE, NULL);
 }
 
 int
