@@ -24,17 +24,19 @@
 /* nautilus-tree-model.c - model for the tree view */
 
 #include <config.h>
-#include "nautilus-tree-model.h"
+#include <stdio.h>
+#include <string.h>
 
-#include "nautilus-tree-node-private.h"
 #include <gtk/gtksignal.h>
 #include <libgnomevfs/gnome-vfs.h>
+#include <libnautilus-private/nautilus-marshal.h>
 #include <libnautilus-private/nautilus-file-attributes.h>
 #include <libnautilus-private/nautilus-icon-factory.h>
 #include <eel/eel-glib-extensions.h>
 #include <eel/eel-gtk-macros.h>
-#include <stdio.h>
-#include <string.h>
+
+#include "nautilus-tree-model.h"
+#include "nautilus-tree-node-private.h"
 
 enum {
 	NODE_CHANGED,
@@ -65,9 +67,9 @@ struct NautilusTreeModelDetails {
 
 
 static void nautilus_tree_model_destroy                          (GtkObject         *object);
-static void nautilus_tree_model_initialize                       (gpointer           object,
+static void nautilus_tree_model_init                       (gpointer           object,
 								  gpointer           klass);
-static void nautilus_tree_model_initialize_class                 (gpointer           klass);
+static void nautilus_tree_model_class_init                 (gpointer           klass);
 static void remove_all_nodes                                     (NautilusTreeModel *model);
 static void nautilus_tree_model_set_root_uri                     (NautilusTreeModel *model,
 								  const char        *root_uri);
@@ -93,12 +95,12 @@ static void nautilus_tree_model_directory_done_loading_callback  (NautilusDirect
 								  NautilusTreeModel *model);
 
 
-EEL_DEFINE_CLASS_BOILERPLATE (NautilusTreeModel, nautilus_tree_model, GTK_TYPE_OBJECT)
+EEL_CLASS_BOILERPLATE (NautilusTreeModel, nautilus_tree_model, GTK_TYPE_OBJECT)
 
 /* infrastructure stuff */
 
 static void
-nautilus_tree_model_initialize_class (gpointer klass)
+nautilus_tree_model_class_init (gpointer klass)
 {
 	GtkObjectClass *object_class;
 
@@ -107,43 +109,44 @@ nautilus_tree_model_initialize_class (gpointer klass)
 	object_class->destroy = nautilus_tree_model_destroy;
 
 	signals[NODE_CHANGED] =
-		gtk_signal_new ("node_changed",
-				GTK_RUN_LAST,
-				object_class->type,
-				GTK_SIGNAL_OFFSET (NautilusTreeModelClass, node_changed),
-				gtk_marshal_NONE__POINTER,
-				GTK_TYPE_NONE, 1, GTK_TYPE_POINTER);
+		g_signal_new ("node_changed",
+		              G_TYPE_FROM_CLASS (object_class),
+		              G_SIGNAL_RUN_LAST,
+		              G_STRUCT_OFFSET (NautilusTreeModelClass, node_changed),
+		              NULL, NULL,
+		              gtk_marshal_VOID__POINTER,
+		              G_TYPE_NONE, 1, G_TYPE_POINTER);
 
 	signals[NODE_REMOVED] =
-		gtk_signal_new ("node_removed",
-				GTK_RUN_LAST,
-				object_class->type,
-				GTK_SIGNAL_OFFSET (NautilusTreeModelClass, node_removed),
-				gtk_marshal_NONE__POINTER,
-				GTK_TYPE_NONE, 1, GTK_TYPE_POINTER);
+		g_signal_new ("node_removed",
+		              G_TYPE_FROM_CLASS (object_class),
+		              G_SIGNAL_RUN_LAST,
+		              G_STRUCT_OFFSET (NautilusTreeModelClass, node_removed),
+		              NULL, NULL,
+		              gtk_marshal_VOID__POINTER,
+		              G_TYPE_NONE, 1, G_TYPE_POINTER);
 
 	signals[NODE_BEING_RENAMED] =
-		gtk_signal_new ("node_being_renamed",
-				GTK_RUN_LAST,
-				object_class->type,
-				GTK_SIGNAL_OFFSET (NautilusTreeModelClass, node_removed),
-				gtk_marshal_NONE__POINTER_POINTER,
-				GTK_TYPE_NONE, 2, GTK_TYPE_STRING, GTK_TYPE_STRING);
+		g_signal_new ("node_being_renamed",
+		              G_TYPE_FROM_CLASS (object_class),
+		              G_SIGNAL_RUN_LAST,
+		              G_STRUCT_OFFSET (NautilusTreeModelClass, node_removed),
+		              NULL, NULL,
+			      nautilus_marshal_VOID__STRING_STRING,
+		              G_TYPE_NONE, 2, G_TYPE_STRING, G_TYPE_STRING);
 
 	signals[DONE_LOADING_CHILDREN] =
-		gtk_signal_new ("done_loading_children",
-				GTK_RUN_LAST,
-				object_class->type,
-				GTK_SIGNAL_OFFSET (NautilusTreeModelClass, done_loading_children),
-				gtk_marshal_NONE__POINTER,
-				GTK_TYPE_NONE, 1, GTK_TYPE_POINTER);
-
-
-	gtk_object_class_add_signals (object_class, signals, LAST_SIGNAL);
+		g_signal_new ("done_loading_children",
+		              G_TYPE_FROM_CLASS (object_class),
+		              G_SIGNAL_RUN_LAST,
+		              G_STRUCT_OFFSET (NautilusTreeModelClass, done_loading_children),
+		              NULL, NULL,
+		              gtk_marshal_VOID__POINTER,
+		              G_TYPE_NONE, 1, G_TYPE_POINTER);
 }
 
 static void
-nautilus_tree_model_initialize (gpointer object, gpointer klass)
+nautilus_tree_model_init (gpointer object, gpointer klass)
 {
 	NautilusTreeModel *model;
 
@@ -160,10 +163,12 @@ destroy_file_hash (GHashTable *hash)
 	if (hash == NULL) {
 		return;
 	}
+#ifdef GNOME2_CONVERSION_COMPLETE
 	eel_g_hash_table_destroy_deep_custom
 		(hash,
 		 (GFunc) nautilus_file_unref, NULL,
 		 NULL, NULL);
+#endif
 }
 
 static void
@@ -201,8 +206,8 @@ nautilus_tree_model_new (const char *root_uri)
 {
 	NautilusTreeModel *model;
 
-	model = NAUTILUS_TREE_MODEL (gtk_object_new (NAUTILUS_TYPE_TREE_MODEL, NULL));
-	gtk_object_ref (GTK_OBJECT (model));
+	model = NAUTILUS_TREE_MODEL (g_object_new (NAUTILUS_TYPE_TREE_MODEL, NULL));
+	g_object_ref (model);
 	gtk_object_sink (GTK_OBJECT (model));
 
 	nautilus_tree_model_set_root_uri (model, root_uri);
@@ -291,7 +296,7 @@ remove_all_nodes (NautilusTreeModel *model)
 						NULL);
 
 	if (model->details->root_node != NULL) {
-		gtk_object_unref (GTK_OBJECT (model->details->root_node));
+		g_object_unref (model->details->root_node);
 		model->details->root_node = NULL;
 	}
 	model->details->root_node_reported = FALSE;
@@ -323,10 +328,10 @@ nautilus_tree_model_monitor_add (NautilusTreeModel         *model,
 			report_root_node_if_possible (model);
 		}
 
-		model->details->root_node_changed_signal_id = gtk_signal_connect 
-			(GTK_OBJECT (nautilus_tree_node_get_file (model->details->root_node)),
+		model->details->root_node_changed_signal_id = g_signal_connect 
+			(nautilus_tree_node_get_file (model->details->root_node),
 			 "changed",
-			 nautilus_tree_model_root_node_file_monitor,
+			 G_CALLBACK (nautilus_tree_model_root_node_file_monitor),
 			 model);
 
 		monitor_attributes = nautilus_icon_factory_get_required_file_attributes ();
@@ -438,24 +443,24 @@ nautilus_tree_model_node_begin_monitoring (NautilusTreeModel         *model,
 
 	directory = nautilus_tree_node_get_directory (node);
 
-	node->details->done_loading_id = gtk_signal_connect 
-		(GTK_OBJECT (directory),
+	node->details->done_loading_id = g_signal_connect 
+		(directory,
 		 "done_loading",
-		 nautilus_tree_model_directory_done_loading_callback,
+		 G_CALLBACK (nautilus_tree_model_directory_done_loading_callback),
 		 model);
 
 	nautilus_tree_model_node_begin_monitoring_no_connect (model, node, force_reload);
 
-	node->details->files_added_id = gtk_signal_connect 
-		(GTK_OBJECT (directory),
+	node->details->files_added_id = g_signal_connect 
+		(directory,
 		 "files_added",
-		 nautilus_tree_model_directory_files_changed_callback,
+		 G_CALLBACK (nautilus_tree_model_directory_files_changed_callback),
 		 model);
 	
-	node->details->files_changed_id = gtk_signal_connect 
-		(GTK_OBJECT (directory),
+	node->details->files_changed_id = g_signal_connect 
+		(directory,
 		 "files_changed",
-		 nautilus_tree_model_directory_files_changed_callback,
+		 G_CALLBACK (nautilus_tree_model_directory_files_changed_callback),
 		 model);	
 }
 
@@ -767,13 +772,13 @@ report_node_changed (NautilusTreeModel *model,
 			g_free (parent_uri);
 		}
 
-		gtk_object_ref (GTK_OBJECT (node));
+		g_object_ref (node);
 		g_hash_table_insert (model->details->file_to_node_map, 
 				     nautilus_tree_node_get_file (node),
 				     node);
 
-		gtk_signal_emit (GTK_OBJECT (model),
-				 signals[NODE_CHANGED],
+		g_signal_emit (model,
+				 signals[NODE_CHANGED], 0,
 				 node);
 
 		connect_unparented_nodes (model, node);
@@ -785,21 +790,21 @@ report_node_changed (NautilusTreeModel *model,
 
 		if (strcmp (file_uri, node_uri) == 0) {
 			/* A normal change */
-			gtk_signal_emit (GTK_OBJECT (model),
-					 signals[NODE_CHANGED],
+			g_signal_emit (model,
+					 signals[NODE_CHANGED], 0,
 					 node);
 		} else {
 			/* A move or rename - model it as a remove followed by an add */
 
-			gtk_object_ref (GTK_OBJECT (node));
+			g_object_ref (node);
 
 
 			/* Let the view know that the rename is happening, this allows
 			 * it to propagate the expansion state from the old name to the
 			 * new name
 			 */
-			gtk_signal_emit (GTK_OBJECT (model),
-					 signals[NODE_BEING_RENAMED],
+			g_signal_emit (model,
+					 signals[NODE_BEING_RENAMED], 0,
 					 node->details->uri, file_uri);
 
 			report_node_removed (model, node);
@@ -819,7 +824,7 @@ report_node_changed (NautilusTreeModel *model,
 
 			report_node_changed (model, node);
 
-			gtk_object_unref (GTK_OBJECT (node));
+			g_object_unref (node);
 		}
 
 		g_free (file_uri);
@@ -860,13 +865,13 @@ report_node_removed_internal (NautilusTreeModel *model,
 		forget_unparented_node (model, node);
 
 		if (signal) {
-			gtk_signal_emit (GTK_OBJECT (model),
-					 signals[NODE_REMOVED],
+			g_signal_emit (model,
+					 signals[NODE_REMOVED], 0,
 					 node);
 		}
 
 
-		gtk_object_unref (GTK_OBJECT (node));
+		g_object_unref (node);
 	} 
 }
 
@@ -882,8 +887,8 @@ static void
 report_done_loading (NautilusTreeModel *model,
 		     NautilusTreeNode  *node)
 {
-	gtk_signal_emit (GTK_OBJECT (model),
-			 signals[DONE_LOADING_CHILDREN],
+	g_signal_emit (model,
+			 signals[DONE_LOADING_CHILDREN], 0,
 			 node);
 }
 
@@ -918,10 +923,10 @@ process_file_change (NautilusTreeModel *model,
 		if (node == NULL) {
 			node = nautilus_tree_node_new (file);
 		} else {
-			gtk_object_ref (GTK_OBJECT (node));
+			g_object_ref (node);
 		}
 		report_node_changed (model, node);
-		gtk_object_unref (GTK_OBJECT (node));
+		g_object_unref (node);
 	}
 }
 
