@@ -1,6 +1,6 @@
 /* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*-
 
-   nautilus-directory.c: Nautilus directory model.
+   nautilus-file-private.h:
  
    Copyright (C) 1999, 2000, 2001 Eazel, Inc.
   
@@ -19,9 +19,12 @@
    Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
   
-   Author: Darin Adler <darin@eazel.com>
+   Author: Darin Adler <darin@bentspoon.com>
 */
 
+#ifndef NAUTILUS_FILE_PRIVATE_H
+#define NAUTILUS_FILE_PRIVATE_H
+
 #include "nautilus-directory.h"
 #include "nautilus-file.h"
 #include "nautilus-monitor.h"
@@ -64,6 +67,10 @@ struct NautilusFileDetails
 
 	GList *mime_list; /* If this is a directory, the list of MIME types in it. */
 	char *top_left_text;
+
+	/* Info you might get from a link (.desktop, .directory or nautilus link) */
+	char *display_name;
+	char *custom_icon_uri;
 	char *activation_uri;
 
 	/* The following is for file operations in progress. Since
@@ -106,8 +113,8 @@ struct NautilusFileDetails
 	eel_boolean_bit got_top_left_text             : 1;
 	eel_boolean_bit top_left_text_is_up_to_date   : 1;
 
-	eel_boolean_bit got_activation_uri            : 1;
-	eel_boolean_bit activation_uri_is_up_to_date  : 1;
+	eel_boolean_bit got_link_info                 : 1;
+	eel_boolean_bit link_info_is_up_to_date       : 1;
 };
 
 NautilusFile *nautilus_file_new_from_info                  (NautilusDirectory      *directory,
@@ -147,3 +154,7 @@ void          nautilus_file_invalidate_attributes_internal (NautilusFile
 GList *       nautilus_file_get_all_attributes             (void);
 
 gboolean      nautilus_file_is_self_owned                  (NautilusFile           *file);
+
+void          nautilus_file_invalidate_count_and_mime_list (NautilusFile              *file);
+
+#endif
