@@ -23,15 +23,15 @@
    Authors: Ramiro Estrugo <ramiro@eazel.com>
 */
 
-#ifndef NAUTILUS_PREFS_GLOBAL_H
-#define NAUTILUS_PREFS_GLOBAL_H
+#ifndef NAUTILUS_GLOBAL_PREFERENCES_H
+#define NAUTILUS_GLOBAL_PREFERENCES_H
 
 #include <eel/eel-preferences.h>
 
-BEGIN_GNOME_DECLS
+G_BEGIN_DECLS
 
 /* Which theme is active */
-#define NAUTILUS_PREFERENCES_THEME				"preferences/theme"
+#define NAUTILUS_PREFERENCES_THEME				"/desktop/gnome/file-views/icon_theme"
 
 /* How wide the sidebar is (or how wide it will be when expanded) */
 #define NAUTILUS_PREFERENCES_SIDEBAR_WIDTH  			"preferences/sidebar_width"
@@ -51,8 +51,8 @@ BEGIN_GNOME_DECLS
 #define NAUTILUS_PREFERENCES_DESKTOP_IS_HOME_DIR                "preferences/desktop_is_home_dir"
 
 /* Display  */
-#define NAUTILUS_PREFERENCES_SHOW_HIDDEN_FILES  		"preferences/show_hidden_files"
-#define NAUTILUS_PREFERENCES_SHOW_BACKUP_FILES  		"preferences/show_backup_files"
+#define NAUTILUS_PREFERENCES_SHOW_HIDDEN_FILES  		"/desktop/gnome/file-views/show_hidden_files"
+#define NAUTILUS_PREFERENCES_SHOW_BACKUP_FILES  		"/desktop/gnome/file-views/show_backup_files"
 #define NAUTILUS_PREFERENCES_SHOW_SPECIAL_FLAGS			"preferences/show_special_flags"
 
 /* Sidebar panels  */
@@ -187,17 +187,9 @@ typedef enum
 /* Gnome session management */
 #define NAUTILUS_PREFERENCES_ADD_TO_SESSION		"preferences/add_to_session"
 
+void nautilus_global_preferences_init                      (void);
+void nautilus_global_preferences_set_default_folder_viewer (const char *iid);
 
-void                    nautilus_global_preferences_initialize                   (void);
+G_END_DECLS
 
-/* Sidebar */
-struct EelScalableFont *nautilus_global_preferences_get_icon_view_smooth_font    (void);
-struct EelScalableFont *nautilus_global_preferences_get_default_smooth_font      (void);
-struct EelScalableFont *nautilus_global_preferences_get_default_smooth_bold_font (void);
-
-void                    nautilus_global_preferences_set_default_folder_viewer    (const char *iid);
-
-
-END_GNOME_DECLS
-
-#endif /* NAUTILUS_PREFS_GLOBAL_H */
+#endif /* NAUTILUS_GLOBAL_PREFERENCES_H */
