@@ -47,9 +47,10 @@
 #include <gdk/gdkx.h>
 #include <gtk/gtkmain.h>
 #include <gtk/gtksignal.h>
+#include <gtk/gtkstock.h>
 #include <libgnome/gnome-i18n.h>
-#include <libgnomeui/gnome-canvas-rect-ellipse.h>
-#include <libgnomeui/gnome-stock.h>
+#include <libgnomecanvas/gnome-canvas-rect-ellipse.h>
+#include <libgnomeui/gnome-stock-icons.h>
 #include <libgnomeui/gnome-uidefs.h>
 #include <libgnomevfs/gnome-vfs-uri.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
@@ -496,11 +497,11 @@ get_data_on_first_target_we_support (GtkWidget *widget, GdkDragContext *context,
 
 	if (drop_types_list == NULL)
 		drop_types_list = gtk_target_list_new (drop_types,
-						       EEL_N_ELEMENTS (drop_types));
+						       G_N_ELEMENTS (drop_types));
 
 	for (target = context->targets; target != NULL; target = target->next) {
 		guint dummy_info;
-		GdkAtom target_atom = GPOINTER_TO_UINT (target->data);
+		GdkAtom target_atom = GDK_POINTER_TO_ATOM (target->data);
 
 		if (gtk_target_list_find (drop_types_list, 
 					  target_atom,
@@ -576,19 +577,19 @@ nautilus_icon_container_item_at (NautilusIconContainer *container,
 }
 
 static char *
-get_container_uri (const NautilusIconContainer *container)
+get_container_uri (NautilusIconContainer *container)
 {
 	char *uri;
 
 	/* get the URI associated with the container */
 	uri = NULL;
-	gtk_signal_emit_by_name (GTK_OBJECT (container), "get_container_uri", &uri);
+	g_signal_emit_by_name (container, "get_container_uri", &uri);
 	return uri;
 }
 
 static gboolean
-nautilus_icon_container_selection_items_local (const NautilusIconContainer *container,
-					       const GList *items)
+nautilus_icon_container_selection_items_local (NautilusIconContainer *container,
+					       GList *items)
 {
 	char *container_uri_string;
 	gboolean result;
@@ -667,7 +668,7 @@ receive_dropped_uri_list (NautilusIconContainer *container, char *uri_list, GdkD
 		return;
 	}
 	
-	gtk_signal_emit_by_name (GTK_OBJECT (container), "handle_uri_list",
+	g_signal_emit_by_name (container, "handle_uri_list",
 				 uri_list,
 				 action,
 				 x, y);
@@ -759,7 +760,8 @@ static gboolean
 confirm_switch_to_manual_layout (NautilusIconContainer *container)
 {
 	const char *message;
-	GnomeDialog *dialog;
+	GtkDialog *dialog;
+	int response;
 
 	/* FIXME bugzilla.gnome.org 40915: Use of the word "directory"
 	 * makes this FMIconView specific. Move these messages into
@@ -787,11 +789,14 @@ confirm_switch_to_manual_layout (NautilusIconContainer *container)
 	}
 
 	dialog = eel_show_yes_no_dialog (message, _("Switch to Manual Layout?"),
-					      _("Switch"), GNOME_STOCK_BUTTON_CANCEL,
-					      GTK_WINDOW (gtk_widget_get_ancestor 
-					 	    (GTK_WIDGET (container), GTK_TYPE_WINDOW)));
+					 _("Switch"), GTK_STOCK_CANCEL,
+					 GTK_WINDOW (gtk_widget_get_ancestor 
+						     (GTK_WIDGET (container), GTK_TYPE_WINDOW)));
+	
+	response = gtk_dialog_run (dialog);
+	gtk_object_destroy (GTK_OBJECT (dialog));
 
-	return gnome_dialog_run (dialog) == GNOME_OK;
+	return response == GTK_RESPONSE_YES;
 }
 
 static void
@@ -873,7 +878,7 @@ handle_nonlocal_move (NautilusIconContainer *container,
 	}
 		
 	/* start the copy */
-	gtk_signal_emit_by_name (GTK_OBJECT (container), "move_copy_items",
+	g_signal_emit_by_name (container, "move_copy_items",
 				 source_uris,
 				 source_item_locations,
 				 target_uri,
@@ -1131,6 +1136,7 @@ nautilus_icon_dnd_update_drop_target (NautilusIconContainer *container,
 				      int x, int y)
 {
 	NautilusIcon *icon;
+	NautilusFile *file;
 	double world_x, world_y;
 	
 	g_assert (NAUTILUS_IS_ICON_CONTAINER (container));
@@ -1152,13 +1158,15 @@ nautilus_icon_dnd_update_drop_target (NautilusIconContainer *container,
 	 */
 
 	/* Find if target icon accepts our drop. */
-	if (icon != NULL 
-		&& (container->details->dnd_info->drag_info.data_type != EEL_ICON_DND_KEYWORD) 
-		&& !nautilus_drag_can_accept_items 
-			(nautilus_file_get (
-				nautilus_icon_container_get_icon_uri (container, icon)), 
-			container->details->dnd_info->drag_info.selection_list)) {
-		icon = NULL;
+	if (icon != NULL && (container->details->dnd_info->drag_info.data_type != EEL_ICON_DND_KEYWORD)) {
+		    file = nautilus_file_get (nautilus_icon_container_get_icon_uri (container, icon));
+
+		    if (!nautilus_drag_can_accept_items (file,
+							 container->details->dnd_info->drag_info.selection_list)) {
+			    icon = NULL;
+		    }
+
+		    nautilus_file_unref (file);
 	}
 
 	set_drop_target (container, icon);
@@ -1211,7 +1219,7 @@ nautilus_icon_dnd_init (NautilusIconContainer *container,
 
 	container->details->dnd_info = g_new0 (NautilusIconDndInfo, 1);
 	eel_drag_init (&container->details->dnd_info->drag_info,
-		drag_types, EEL_N_ELEMENTS (drag_types), stipple);
+		drag_types, G_N_ELEMENTS (drag_types), stipple);
 
 	/* Set up the widget as a drag destination.
 	 * (But not a source, as drags starting from this widget will be
@@ -1219,43 +1227,39 @@ nautilus_icon_dnd_init (NautilusIconContainer *container,
 	 */
 	gtk_drag_dest_set  (GTK_WIDGET (container),
 			    0,
-			    drop_types, EEL_N_ELEMENTS (drop_types),
+			    drop_types, G_N_ELEMENTS (drop_types),
 			    GDK_ACTION_COPY | GDK_ACTION_MOVE | GDK_ACTION_LINK
 			    | GDK_ACTION_ASK);
 
 	/* Messages for outgoing drag. */
-	gtk_signal_connect (GTK_OBJECT (container), "drag_data_get",
-			    GTK_SIGNAL_FUNC (drag_data_get_callback), NULL);
-	gtk_signal_connect (GTK_OBJECT (container), "drag_end",
-			    GTK_SIGNAL_FUNC (drag_end_callback), NULL);
+	g_signal_connect (container, "drag_data_get",
+			    G_CALLBACK (drag_data_get_callback), NULL);
+	g_signal_connect (container, "drag_end",
+			    G_CALLBACK (drag_end_callback), NULL);
 
 	/* Messages for incoming drag. */
-	gtk_signal_connect (GTK_OBJECT (container), "drag_data_received",
-			    GTK_SIGNAL_FUNC (drag_data_received_callback), NULL);
-	gtk_signal_connect (GTK_OBJECT (container), "drag_motion",
-			    GTK_SIGNAL_FUNC (drag_motion_callback), NULL);
-	gtk_signal_connect (GTK_OBJECT (container), "drag_drop",
-			    GTK_SIGNAL_FUNC (drag_drop_callback), NULL);
-	gtk_signal_connect (GTK_OBJECT (container), "drag_leave",
-			    GTK_SIGNAL_FUNC (drag_leave_callback), NULL);
+	g_signal_connect (container, "drag_data_received",
+			    G_CALLBACK (drag_data_received_callback), NULL);
+	g_signal_connect (container, "drag_motion",
+			    G_CALLBACK (drag_motion_callback), NULL);
+	g_signal_connect (container, "drag_drop",
+			    G_CALLBACK (drag_drop_callback), NULL);
+	g_signal_connect (container, "drag_leave",
+			    G_CALLBACK (drag_leave_callback), NULL);
 
 }
 
 void
 nautilus_icon_dnd_fini (NautilusIconContainer *container)
 {
-	g_return_if_fail (container != NULL);
 	g_return_if_fail (NAUTILUS_IS_ICON_CONTAINER (container));
-	g_return_if_fail (container->details->dnd_info != NULL);
 
-	stop_auto_scroll (container);
-	if (container->details->dnd_info->shadow != NULL) {
-		/* FIXME bugzilla.gnome.org 42484: 
-		 * Is a destroy really sufficient here? Who does the unref? */
-		gtk_object_destroy (GTK_OBJECT (container->details->dnd_info->shadow));
+	if (container->details->dnd_info != NULL) {
+		stop_auto_scroll (container);
+
+		eel_drag_finalize (&container->details->dnd_info->drag_info);
+		container->details->dnd_info = NULL;
 	}
-
-	eel_drag_finalize (&container->details->dnd_info->drag_info);
 }
 
 void
@@ -1310,7 +1314,7 @@ nautilus_icon_dnd_begin_drag (NautilusIconContainer *container,
         y_offset = dnd_info->drag_info.start_y - window_rect.y0;
         
         /* set the icon for dragging */
-        eel_drag_set_icon_pixbuf (context, pixbuf, x_offset, y_offset);
+        gtk_drag_set_icon_pixbuf (context, pixbuf, x_offset, y_offset);
 }
 
 static gboolean
