@@ -36,6 +36,7 @@
 #include <gtk/gtkmain.h>
 #include <gtk/gtksignal.h>
 #include <gtk/gtktext.h>
+#include <string.h>
 
 typedef void (* EditableFunction) (GtkEditable *editable);
 
@@ -44,48 +45,6 @@ static void disconnect_set_up_in_control_handlers (GtkObject *object,
 static void selection_changed_callback            (GtkWidget *widget,
 						   gpointer callback_data);
 
-static void
-do_with_fake_current_event (EditableFunction function,
-			    GtkEditable *editable)
-{
-	GdkEvent *current_event;
-	GdkEvent fake_event;
-	GtkWidget *fake_widget;
-
-	/* Handle the simple case where no fakery is required. */
-	current_event = gtk_get_current_event ();
-	if (current_event != NULL) {
-		gdk_event_free (current_event);
-		(* function) (editable);
-		return;
-	}
-
-	/* Call the function inside a fake event, so the event is
-	 * non-NULL. This works around the gtk bug described in
-	 * http://bugzilla.gnome.org/show_bug.cgi?id=51889 where the
-	 * event must not be NULL.
-	 */
-
-	/* Make widget. */
-	fake_widget = gtk_invisible_new ();
-	gtk_signal_connect_object (GTK_OBJECT (fake_widget),
-				   "client_event",
-				   function,
-				   GTK_OBJECT (editable));
-	gtk_widget_realize (fake_widget);
-
-	/* Make event. */
-	memset (&fake_event, 0, sizeof (fake_event));
-	fake_event.type = GDK_CLIENT_EVENT;
-	fake_event.any.window = fake_widget->window;
-
-	/* Handle event, calling through to function. */
-	gtk_main_do_event (&fake_event);
-
-	/* Discard widget. */
-	gtk_widget_unref (fake_widget);
-}
-
 static void
 cut_callback (BonoboUIComponent *ui,
 	      gpointer callback_data,
@@ -94,8 +53,7 @@ cut_callback (BonoboUIComponent *ui,
 	g_assert (BONOBO_IS_UI_COMPONENT (ui));
 	g_assert (strcmp (command_name, "Cut") == 0);
 	
-	do_with_fake_current_event (gtk_editable_cut_clipboard,
-				    GTK_EDITABLE (callback_data));
+	gtk_editable_cut_clipboard (GTK_EDITABLE (callback_data));
 }
 
 static void
@@ -106,8 +64,7 @@ copy_callback (BonoboUIComponent *ui,
 	g_assert (BONOBO_IS_UI_COMPONENT (ui));
 	g_assert (strcmp (command_name, "Copy") == 0);
 	
-	do_with_fake_current_event (gtk_editable_copy_clipboard,
-				    GTK_EDITABLE (callback_data));
+	gtk_editable_copy_clipboard (GTK_EDITABLE (callback_data));
 }
 
 static void
@@ -118,8 +75,7 @@ paste_callback (BonoboUIComponent *ui,
 	g_assert (BONOBO_IS_UI_COMPONENT (ui));
 	g_assert (strcmp (command_name, "Paste") == 0);
 	
-	do_with_fake_current_event (gtk_editable_paste_clipboard,
-				    GTK_EDITABLE (callback_data));
+	gtk_editable_paste_clipboard (GTK_EDITABLE (callback_data));
 }
 
 static void
@@ -135,19 +91,9 @@ clear_callback (BonoboUIComponent *ui,
 
 static void
 select_all (GtkEditable *editable)
-{
-	int end;
-
-	/* Workaround for bug in GtkText. It can't handle a -1
-	 * passed in to set_position.
-	 */
-	end = -1;
-	if (GTK_IS_TEXT (editable)) {
-		end = gtk_text_get_length (GTK_TEXT (editable));
-	}
-	
-	gtk_editable_set_position (editable, end);
-	gtk_editable_select_region (editable, 0, end);
+{	
+	gtk_editable_set_position (editable, -1);
+	gtk_editable_select_region (editable, 0, -1);
 }
 
 static gboolean
@@ -157,11 +103,7 @@ select_all_idle_callback (gpointer callback_data)
 
 	editable = GTK_EDITABLE (callback_data);
 
-	if (!GTK_OBJECT_DESTROYED (GTK_OBJECT (editable))) {
-		select_all (editable);
-	}
-
-	gtk_object_unref (GTK_OBJECT (editable));
+	select_all (editable);
 
 	return FALSE;
 }
@@ -171,14 +113,20 @@ select_all_callback (BonoboUIComponent *ui,
 		     gpointer callback_data,
 		     const char *command_name)
 {
+	GSource *source;
 	GtkEditable *editable;
 
 	g_assert (BONOBO_IS_UI_COMPONENT (ui));
 	g_assert (strcmp (command_name, "Select All") == 0);
 
 	editable = GTK_EDITABLE (callback_data);
-	gtk_object_ref (GTK_OBJECT (editable));
-	gtk_idle_add (select_all_idle_callback, editable);
+
+	source = g_idle_source_new ();
+	g_source_set_callback (source, select_all_idle_callback, editable, NULL);
+	g_signal_connect_swapped (editable, "destroy",
+				  G_CALLBACK (g_source_destroy), source);
+	g_source_attach (source, NULL);
+	g_source_unref (source);
 }
 
 static void
@@ -257,21 +205,21 @@ typedef struct {
 static gboolean
 clipboard_items_are_merged_in (GtkWidget *widget)
 {
-	return GPOINTER_TO_INT (gtk_object_get_data (GTK_OBJECT (widget),
+	return GPOINTER_TO_INT (g_object_get_data (G_OBJECT (widget),
 						     "Nautilus:clipboard_menu_items_merged"));
 }
 
 static void
-set_clipboard_items_are_merged_in (GtkObject *widget_as_object,
+set_clipboard_items_are_merged_in (GObject *widget_as_object,
 				   gboolean merged_in)
 {
-	gtk_object_set_data (widget_as_object,
-			     "Nautilus:clipboard_menu_items_merged",
-			     GINT_TO_POINTER (merged_in));
+	g_object_set_data (widget_as_object,
+			   "Nautilus:clipboard_menu_items_merged",
+			   GINT_TO_POINTER (merged_in));
 }
 
 static void
-merge_in_clipboard_menu_items (GtkObject *widget_as_object,
+merge_in_clipboard_menu_items (GObject *widget_as_object,
 			       TargetCallbackData *target_data)
 {
 	BonoboUIComponent *ui;
@@ -283,17 +231,16 @@ merge_in_clipboard_menu_items (GtkObject *widget_as_object,
 	container = target_data->container;
 	add_selection_callback = target_data->editable_shares_selection_changes;
 
-	bonobo_ui_component_set_container (ui,
-					   container);
+	bonobo_ui_component_set_container (ui, container, NULL);
 	bonobo_ui_component_freeze (ui, NULL);
 	bonobo_ui_util_set_ui (ui,
 			       DATADIR,
 			       "nautilus-clipboard-ui.xml",
-			       "nautilus");
+			       "nautilus", NULL);
 	
 	if (add_selection_callback) {
-		gtk_signal_connect_after (GTK_OBJECT (widget_as_object), "selection_changed",
-					  selection_changed_callback, target_data);
+		g_signal_connect_after (widget_as_object, "selection_changed",
+					G_CALLBACK (selection_changed_callback), target_data);
 		selection_changed_callback (GTK_WIDGET (widget_as_object),
 					    target_data);
 			
@@ -306,7 +253,7 @@ merge_in_clipboard_menu_items (GtkObject *widget_as_object,
 }
 
 static void
-merge_out_clipboard_menu_items (GtkObject *widget_as_object,
+merge_out_clipboard_menu_items (GObject *widget_as_object,
 				TargetCallbackData *target_data)
 
 {
@@ -316,12 +263,14 @@ merge_out_clipboard_menu_items (GtkObject *widget_as_object,
 	g_assert (target_data != NULL);
 	ui = BONOBO_UI_COMPONENT (target_data->component);
 	selection_callback_was_added = target_data->editable_shares_selection_changes;
-	bonobo_ui_component_unset_container (ui);
+	bonobo_ui_component_unset_container (ui, NULL);
 
 	if (selection_callback_was_added) {
-		gtk_signal_disconnect_by_func (GTK_OBJECT (widget_as_object),
-					       selection_changed_callback,
-					       target_data);
+		g_signal_handlers_disconnect_matched (widget_as_object,
+						      G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA,
+						      0, 0, NULL,
+						      G_CALLBACK (selection_changed_callback),
+						      target_data);
 	}
 	set_clipboard_items_are_merged_in (widget_as_object, FALSE);
 }
@@ -343,13 +292,11 @@ focus_changed_callback (GtkWidget *widget,
 	ui = target_data->component;
 	if (GTK_WIDGET_HAS_FOCUS (widget)) {
 		if (!clipboard_items_are_merged_in (widget)) {
-			merge_in_clipboard_menu_items (GTK_OBJECT (widget),
-						       target_data);
+			merge_in_clipboard_menu_items (G_OBJECT (widget), target_data);
 		}
 	} else {
 		if (clipboard_items_are_merged_in (widget)) {
-			merge_out_clipboard_menu_items (GTK_OBJECT (widget),
-							target_data);
+			merge_out_clipboard_menu_items (G_OBJECT (widget), target_data);
 		}
 
 	}
@@ -362,6 +309,7 @@ selection_changed_callback (GtkWidget *widget,
 	TargetCallbackData *target_data;
 	BonoboUIComponent *component;
 	GtkEditable *editable;
+	int start, end;
 
 	target_data = (TargetCallbackData *) callback_data;
 	g_assert (target_data != NULL);
@@ -369,7 +317,7 @@ selection_changed_callback (GtkWidget *widget,
 	component = target_data->component;
 	editable = GTK_EDITABLE (widget);
 
-	if (editable->selection_start_pos != editable->selection_end_pos) {
+	if (gtk_editable_get_selection_bounds (editable, &start, &end) && start != end) {
 		set_clipboard_menu_items_sensitive (component);
 	} else {
 		set_clipboard_menu_items_insensitive (component);
@@ -389,7 +337,7 @@ target_destroy_callback (GtkObject *object,
 	/* Disconnect the component from the container, and then free
 	 * everything.
 	 */
-	bonobo_ui_component_unset_container (target_data->component);
+	bonobo_ui_component_unset_container (target_data->component, NULL);
 	bonobo_object_unref (BONOBO_OBJECT (target_data->component));
 	bonobo_object_release_unref (target_data->container, NULL);
 	g_free (target_data);
@@ -444,13 +392,13 @@ nautilus_clipboard_set_up_editable (GtkEditable *target,
 		 ui_container,
 		 shares_selection_changes);
 
-	gtk_signal_connect_after (GTK_OBJECT (target), "focus_in_event",
-				  focus_changed_callback, target_data);
-	gtk_signal_connect_after (GTK_OBJECT (target), "focus_out_event",
-				  focus_changed_callback, target_data);
+	g_signal_connect_after (target, "focus_in_event",
+				G_CALLBACK (focus_changed_callback), target_data);
+	g_signal_connect_after (target, "focus_out_event",
+				G_CALLBACK (focus_changed_callback), target_data);
 
-	gtk_signal_connect (GTK_OBJECT (target), "destroy",
-			    target_destroy_callback, target_data);
+	g_signal_connect (target, "destroy",
+			    G_CALLBACK (target_destroy_callback), target_data);
 	
 	/* Call the focus changed callback once to merge if the window is
 	 * already in focus.
@@ -462,7 +410,7 @@ nautilus_clipboard_set_up_editable (GtkEditable *target,
 static gboolean
 widget_was_set_up_with_selection_sensitivity (GtkWidget *widget)
 {
-	return GPOINTER_TO_INT (gtk_object_get_data (GTK_OBJECT (widget),
+	return GPOINTER_TO_INT (g_object_get_data (G_OBJECT (widget),
 						     "Nautilus:shares_selection_changes"));
 }
 
@@ -481,7 +429,7 @@ first_focus_callback (GtkWidget *widget,
 	/* Do the rest of the setup. */
 	nautilus_clipboard_set_up_editable
 		(GTK_EDITABLE (widget),
-		 bonobo_control_get_remote_ui_container (BONOBO_CONTROL (callback_data)),
+		 bonobo_control_get_remote_ui_container (BONOBO_CONTROL (callback_data), NULL),
 		 widget_was_set_up_with_selection_sensitivity (widget));
 }
 
@@ -504,7 +452,7 @@ nautilus_clipboard_set_up_editable_in_control (GtkEditable *target,
 	if (GTK_WIDGET_HAS_FOCUS (target)) {
 		nautilus_clipboard_set_up_editable
 			(target,
-			 bonobo_control_get_remote_ui_container (control),
+			 bonobo_control_get_remote_ui_container (control, NULL),
 			 shares_selection_changes);
 		return;
 	}
@@ -516,27 +464,31 @@ nautilus_clipboard_set_up_editable_in_control (GtkEditable *target,
 	/* We'd like to use gtk_signal_connect_while_alive, but it's
 	 * not compatible with gtk_signal_disconnect calls.
 	 */
-	gtk_object_set_data (GTK_OBJECT (target),
-			     "Nautilus:shares_selection_changes",
-			     GINT_TO_POINTER (shares_selection_changes));
-	gtk_signal_connect (GTK_OBJECT (target),
-			    "focus_in_event",
-			    first_focus_callback,
-			    control);
-	gtk_signal_connect (GTK_OBJECT (target),
-			    "destroy",
-			    control_destroyed_callback,
-			    control);
+	g_object_set_data (G_OBJECT (target),
+			   "Nautilus:shares_selection_changes",
+			   GINT_TO_POINTER (shares_selection_changes));
+	g_signal_connect (target,
+			  "focus_in_event",
+			  G_CALLBACK (first_focus_callback),
+			  control);
+	g_signal_connect (target,
+			  "destroy",
+			  G_CALLBACK (control_destroyed_callback),
+			  control);
 }
 
 static void
 disconnect_set_up_in_control_handlers (GtkObject *object,
 				       gpointer callback_data)
 {
-	gtk_signal_disconnect_by_func (object,
-				       first_focus_callback,
-				       callback_data);
-	gtk_signal_disconnect_by_func (object,
-				       control_destroyed_callback,
-				       callback_data);
+	g_signal_handlers_disconnect_matched (object,
+					      G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA,
+					      0, 0, NULL,
+					      G_CALLBACK (first_focus_callback),
+					      callback_data);
+	g_signal_handlers_disconnect_matched (object,
+					      G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA,
+					      0, 0, NULL,
+					      G_CALLBACK (control_destroyed_callback),
+					      callback_data);
 }
