@@ -35,26 +35,32 @@
 
 #include <libnautilus/nautilus-view.h>
 
-BEGIN_GNOME_DECLS
+G_BEGIN_DECLS
 
 typedef NautilusView * (*NautilusViewCreateFunction) (const char *iid, void *user_data);
 
 int nautilus_view_standard_main        (const char                 *executable_name,
 					const char                 *version,
+					const char                 *gettext_package_name,
+					const char                 *gettext_locale_directory,
 					int                         argc,
 					char                      **argv,
 					const char                 *factory_iid,
 					const char                 *view_iid,
 					NautilusViewCreateFunction  create_function,
+					GVoidFunc                   post_initialize_callback,
 					void                       *user_data);
 
 int nautilus_view_standard_main_multi  (const char                 *executable_name,
 					const char                 *version,
+					const char                 *gettext_package_name,
+					const char                 *gettext_locale_directory,
 					int                         argc,
 					char                      **argv,
 					const char                 *factory_iid,
 					GList                      *view_iids,       /* GList<const char *> */
 					NautilusViewCreateFunction  create_function,
+					GVoidFunc                   post_initialize_callback,
 					void                       *user_data);
 
 /* standard handy create function (pass the _get_type function for the
@@ -62,6 +68,6 @@ int nautilus_view_standard_main_multi  (const char                 *executable_n
  */
 NautilusView * nautilus_view_create_from_get_type_function (const char *iid, void *user_data);
 
-END_GNOME_DECLS
+G_END_DECLS
 
 #endif /* NAUTILUS_VIEW_STANDARD_MAIN_H */
